==> haskell-fsnotify-0.2.1-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fsnotify
version: 0.2.1
id: fsnotify-0.2.1-AbK6POsDNvc2W7OcESHkcO
key: fsnotify-0.2.1-AbK6POsDNvc2W7OcESHkcO
license: BSD3
maintainer: Greg Weber <greg@gregweber.info>, Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/haskell-fswatch/hfsnotify
synopsis: Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.
category: Filesystem
author: Mark Dittmer <mark.s.dittmer@gmail.com>
exposed: True
exposed-modules:
    System.FSNotify System.FSNotify.Devel
hidden-modules: System.FSNotify.Listener System.FSNotify.Path
                System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
abi: 3474bc1969dc591e7209bb9589cb88db
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/fsnotify-0.2.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/fsnotify-0.2.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/fsnotify-0.2.1
hs-libraries: HSfsnotify-0.2.1-AbK6POsDNvc2W7OcESHkcO
depends:
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM base-4.9.0.0 containers-0.5.7.1
    directory-1.2.6.2 filepath-1.4.1.0
    hinotify-0.3.9-62aFIb4WDdT42crbzG7YZs
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
haddock-interfaces: /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html: /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify-0.2.1-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fsnotify
version: 0.2.1
id: fsnotify-0.2.1-F3SZJZ6KmEOGHbHJYEMCVP
key: fsnotify-0.2.1-F3SZJZ6KmEOGHbHJYEMCVP
license: BSD3
maintainer: Greg Weber <greg@gregweber.info>, Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/haskell-fswatch/hfsnotify
synopsis: Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.
category: Filesystem
author: Mark Dittmer <mark.s.dittmer@gmail.com>
exposed: True
exposed-modules:
    System.FSNotify System.FSNotify.Devel
hidden-modules: System.FSNotify.Listener System.FSNotify.Path
                System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
abi: fd361ec481bf554231019c6c034aba0f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/fsnotify-0.2.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/fsnotify-0.2.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/fsnotify-0.2.1
hs-libraries: HSfsnotify-0.2.1-F3SZJZ6KmEOGHbHJYEMCVP
depends:
    async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4 base-4.9.0.0
    containers-0.5.7.1 directory-1.2.6.2 filepath-1.4.1.0
    hinotify-0.3.9-HLzp1gj53or7W6Eno8PTQp
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
haddock-interfaces: /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html: /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
